@@ -88,7 +88,6 @@ type FnSetMemAccess = fn(
 
 #[derive(Debug)]
 pub struct LibXenCtrl {
-    lib: Library,
     pub interface_open: RawSymbol<FnInterfaceOpen>,
     pub clear_last_error: RawSymbol<FnClearLastError>,
     pub get_last_error: RawSymbol<FnGetLastError>,
@@ -192,7 +191,6 @@ impl LibXenCtrl {
         let interface_close = interface_close_sym.into_raw();
 
         Ok(LibXenCtrl {
-            lib,
             interface_open,
             clear_last_error,
             get_last_error,
